Index: src/arm/macro-assembler-arm.h |
diff --git a/src/arm/macro-assembler-arm.h b/src/arm/macro-assembler-arm.h |
index e37bb5e1c21388bc1e393321218e9eeca64dcaf3..6dc2b7ae892cebb22e19a5ef39e4906834cc25d9 100644 |
--- a/src/arm/macro-assembler-arm.h |
+++ b/src/arm/macro-assembler-arm.h |
@@ -87,14 +87,14 @@ class MacroAssembler: public Assembler { |
void EnterConstructFrame() { EnterFrame(StackFrame::CONSTRUCT); } |
void LeaveConstructFrame() { LeaveFrame(StackFrame::CONSTRUCT); } |
// Enter specific kind of exit frame; either EXIT or |
// EXIT_DEBUG. Expects the number of arguments in register r0 and |
// the builtin function to call in register r1. Exits with argc in |
// r4, argv in r6, and and the builtin function to call in r5. |
- void EnterExitFrame(StackFrame::Type type); |
+ void EnterExitFrame(ExitFrame::Mode mode); |
// Leave the current exit frame. Expects the return value in r0. |
- void LeaveExitFrame(StackFrame::Type type); |
+ void LeaveExitFrame(ExitFrame::Mode mode); |
// Align the stack by optionally pushing a Smi zero. |
void AlignStack(int offset); |
@@ -87,14 +87,14 @@ class MacroAssembler: public Assembler { |
void EnterConstructFrame() { EnterFrame(StackFrame::CONSTRUCT); } |
void LeaveConstructFrame() { LeaveFrame(StackFrame::CONSTRUCT); } |
- // Enter specific kind of exit frame; either EXIT or |
- // EXIT_DEBUG. Expects the number of arguments in register r0 and |
+ // Enter specific kind of exit frame; either normal or debug mode. |
+ // Expects the number of arguments in register r0 and |
// the builtin function to call in register r1. Exits with argc in |
// r4, argv in r6, and and the builtin function to call in r5. |